cmoncrawl.processor.extraction.utils — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.processor.extraction.utils

Functions

`all_same_transform`(dict, fc) |
`chain_transforms`(trans) |
`check_required`(required_fields, extractor_name) |
`combine_dicts`(dicts) |
`extract_transform`(tag, extract_dict, ...) |
`get_attribute_transform`(attr_name) |
`get_tag_transform`(tag_desc) |
`get_tags_transform`(tag_desc) |
`get_text_list_transform`([sep]) |
`get_text_transform`(tag[, recursive]) |
`transform`(dict, transforms) |